@@ -20,16 +20,12 @@
 }
 
 
-if (!isGeneric("area")) {
-	setGeneric("area", function(x, ...)
-		standardGeneric("area"))
-}	
 
 setMethod('area', signature(x='SpatialPolygons'), 
 	function(x, ...) {
 		if (couldBeLonLat(x)) {
 			if (!isLonLat(x)) {
-				warning('assuming that the CRS is longitude/latitude!')
+				warning('assuming that the crs is longitude/latitude!')
 			}
 			lonlat = TRUE
 		} else {
